@@ -13,6 +13,10 @@
 # include "osdep-ppc.h"
 #endif
 
+#ifdef __arm__
+# include "osdep-arm.h"
+#endif
+
 #if defined(__GLIBC__) && __GLIBC__ >= 2
 # include <netinet/if_ether.h>
 #else
