@@ -5,6 +5,9 @@
 #include <errno.h>
 #include <sys/types.h>
 
+#include <config.h>
+
+#include <support.h>
 #include <xcio.h>
 
 static void
