@@ -3,6 +3,10 @@
 #include <X11/Shell.h>
 #include <stdio.h>
 #include <signal.h>
+
+#include <config.h>
+#include <support.h>
+
 #include <xcio.h>
 #include "xppxp.h"
 #include "config.h"
