@@ -230,7 +230,8 @@ AEnvToStr(struct env_s *esp, env_t typemask)
 	break;
     case ENV_STRING:
 	if (*(char **)esp->d.entry)
-	    sprintf(strenv, "%s", *(char **)esp->d.entry);
+	    snprintf(strenv, sizeof(strenv), "%s",
+		     *(char **)esp->d.entry);
 	break;
     case ENV_SET:
 	esp->d.set(0, &esp->name, strenv);
