@@ -6,7 +6,7 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <netdb.h>
-#ifdef linux
+#if defined(linux) || defined(sun)
 #include <net/if_arp.h>
 #else
 #include <netinet/in_systm.h>
@@ -35,6 +35,7 @@
 #define	EXPIRE_TCP	(300/EXPIRE_INTERVAL)	/* 5min */
 #define	EXPIRE_UDP	(60/EXPIRE_INTERVAL)	/* 1min */
 #define	EXPIRE_ICMP	(10/EXPIRE_INTERVAL)	/* 10sec */
+#define	EXPIRE_NOW	(15/EXPIRE_INTERVAL)	/* 15sec */
 
 #include "log.h"
 #include "xcio.h"
@@ -201,10 +202,13 @@ IpFilterExpire(struct ipfilter_s **head, u_int8_t mask)
 	    IpFilterFree(ifp);
 	    ifp = ifp1;
 	} else {
+#if 0
 	    if (ifp->flag & IPFF_WILLEXPIRE) {
 		ifp->flag &= ~IPFF_WILLEXPIRE;
 		ifp->flag |= IPFF_EXPIRED;
-	    } else if (ifp->expire) {
+	    } else
+#endif
+	    if (ifp->expire) {
 		ifp->expire --;
 		if (!ifp->expire) {
 		    if (ifp->ad_mod && ifp->ad_mod->cused) {
@@ -1202,9 +1206,11 @@ IpFilterCheck(f_type_t ff, u_char *buf, int *lenp, time_t *idlep,
 		if (!(~(tcphp->th_flags) & ifp->tcp_mask)) continue;
 	    }
 	    if (ifp->flag & IPFF_AUTO) {
-		if (tcphp->th_flags & (TH_FIN|TH_RST))
+		if (tcphp->th_flags & (TH_FIN|TH_RST)) {
 		    ifp->flag |= IPFF_WILLEXPIRE;
-		else ifp->expire = EXPIRE_TCP;
+		    ifp->expire = EXPIRE_NOW;
+		} else if (!(ifp->flag & IPFF_WILLEXPIRE))
+		    ifp->expire = EXPIRE_TCP;
 	    }
 	} else if (ifp->flag & IPFF_AUTO) ifp->expire = EXPIRE_UDP;
     packet_matched:
