@@ -51,7 +51,7 @@ static struct ipcpreg_s xReg;
 struct ipcpreg_s ipcprReg, ipcplReg;
 
 static struct fsmreg_s ipcpFsm;
-static struct cpcodeop_s ipcpCop[IPCPCODE_MAX];
+static struct cpcodeop_s ipcpCop[IPCPCODE_MAX + 1];
 static struct cptypeop_s ipcpTop[]={
     {
 	"IP-Addresses", NULL,
@@ -671,16 +671,16 @@ IpcpSetup()
     ipcpFsm.name = "IPCP";
     ipcpFsm.timer.name = "IPCPFSM";
     ipcpFsm.timer.arg = &ipcpFsm;
-    ipcpCop[CPCODE_CONF_REQ-1].fsmevent = RCR;
-    ipcpCop[CPCODE_CONF_REQ-1].encode = IpcpEncodeReg;
-    ipcpCop[CPCODE_CONF_ACK-1].fsmevent = RCA;
-    ipcpCop[CPCODE_CONF_ACK-1].encode = IpcpEncodeReg;
-    ipcpCop[CPCODE_CONF_NAK-1].fsmevent = RCN;
-    ipcpCop[CPCODE_CONF_NAK-1].encode = IpcpEncodeReg;
-    ipcpCop[CPCODE_TERM_REQ-1].fsmevent = RTR;
-    ipcpCop[CPCODE_CONF_REJ-1].encode = IpcpEncodeReg;
-    ipcpCop[CPCODE_TERM_ACK-1].fsmevent = RTA;
-    ipcpCop[CPCODE_CONF_REJ-1].fsmevent = RCJ;
+    ipcpCop[CPCODE_CONF_REQ].fsmevent = RCR;
+    ipcpCop[CPCODE_CONF_REQ].encode = IpcpEncodeReg;
+    ipcpCop[CPCODE_CONF_ACK].fsmevent = RCA;
+    ipcpCop[CPCODE_CONF_ACK].encode = IpcpEncodeReg;
+    ipcpCop[CPCODE_CONF_NAK].fsmevent = RCN;
+    ipcpCop[CPCODE_CONF_NAK].encode = IpcpEncodeReg;
+    ipcpCop[CPCODE_TERM_REQ].fsmevent = RTR;
+    ipcpCop[CPCODE_CONF_REJ].encode = IpcpEncodeReg;
+    ipcpCop[CPCODE_TERM_ACK].fsmevent = RTA;
+    ipcpCop[CPCODE_CONF_REJ].fsmevent = RCJ;
     ipcpFsm.tlu = TLU;
     ipcpFsm.tlf = TLF;
     ipcpFsm.tld = TLD;
