@@ -5,12 +5,12 @@
 #include <sys/types.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
-#ifdef	linux
+#ifdef linux
 #include <net/if.h>	/* for IFNAMSIZ */
 #else
 #include <sys/socket.h>
 #include <net/if.h>
-#ifndef	if_mtu
+#if !defined(if_mtu) && !defined(sun)
 #include <net/if_var.h>
 #endif
 #endif
@@ -45,6 +45,7 @@ struct lcpopt_s {
 
 static struct lcpopt_s lcpOpt;
 
+#define	LCPCONF_VENDOR_SPEC	0
 #define	LCPCONF_MRU		1
 #define	LCPCONF_ACCM		2
 #define	LCPCONF_AUTH		3
@@ -67,7 +68,14 @@ static struct lcpopt_s lcpOpt;
 #define	LCPCONF_DCEID		21
 #define	LCPCONF_ML_PPLUS	22
 #define	LCPCONF_BACP_LD		23
-#define	LCPCONF_MAX		24
+#define	LCPCONF_AUTH_OPTION	24
+#define	LCPCONF_COBS		25
+#define	LCPCONF_PREFIX_ELISION	26
+#define	LCPCONF_ML_HEADER	27
+#define	LCPCONF_I18N		28
+#define	LCPCONF_SONET_SDH	29
+#define	LCPCONF_MUXING		30
+#define	LCPCONF_MAX		31
 
 static const char *callbackTypes[]={
     "user", "dial", "id", "E.164", "name", "???", "CBCP", "none"
@@ -83,7 +91,7 @@ static int AuthProtoCoder(), QualProtoCoder();
 static int CallbackCoder();
 
 static struct fsmreg_s lcpFsm;
-static struct cpcodeop_s lcpCop[LCPCODE_MAX];
+static struct cpcodeop_s lcpCop[LCPCODE_MAX + 1];
 static struct cptypeop_s lcpTop[]={
     {
 	"Maximum-Receive-Unit", TostrD16,
@@ -297,6 +305,8 @@ LcpEncodeRejectReg(u_char *buf, struct lcpreg_s *lcr)
 static void
 TLD(struct fsmreg_s *fsm)
 {
+    phaseShift = PHASE_PREV;
+/*    PhasePrev();	/* 2000Dec27 */
 /*
     const char *oldpath;
 
@@ -388,15 +398,19 @@ RCR(u_char *buf, int n)
 	    goto reject;
 	    break;
 	case LCPCONF_MAGIC:
-	    if (!lcprReg.nbo_magic ||
-		xReg.nbo_magic == lcprReg.nbo_magic) continue;
 	    if (!lcplReg.nbo_magic &&
 		xReg.nbo_magic == lcplReg.nbo_magic) {
 		/* loop back !! */
 		Logf(LOG_CP, " Loopback detected\n");
 		return(0);
 	    }
+#if 0
+	    if (!lcprReg.nbo_magic ||
+		xReg.nbo_magic == lcprReg.nbo_magic) continue;
 	    break;
+#else	    /* 2000Dec27 */
+	    continue;
+#endif
 	case LCPCONF_CALLBACK:
 #if 0
 	    goto reject;
@@ -732,24 +746,24 @@ LcpSetup()
     RegisterCp(&lcpState, &lcpFsm);
     lcpFsm.timer.name = "LCPFSM";
     lcpFsm.timer.arg = &lcpFsm;
-    lcpCop[CPCODE_CONF_REQ-1].fsmevent = RCR;
-    lcpCop[CPCODE_CONF_REQ-1].encode = LcpEncodeReg;
-    lcpCop[CPCODE_CONF_ACK-1].fsmevent = RCA;
-    lcpCop[CPCODE_CONF_ACK-1].encode = LcpEncodeReg;
-    lcpCop[CPCODE_CONF_NAK-1].fsmevent = RCN;
-    lcpCop[CPCODE_CONF_NAK-1].encode = LcpEncodeReg;
-    lcpCop[CPCODE_CONF_REJ-1].fsmevent = RCJ;
-    lcpCop[CPCODE_CONF_REJ-1].encode = LcpEncodeRejectReg;
-/*    lcpCop[CPCODE_CODE_REJ-1].fsmevent = RXCJ;*/
-    lcpCop[CPCODE_PROT_REJ-1].fsmevent = RXPJ;
-    lcpCop[CPCODE_TERM_REQ-1].fsmevent = RTR;
-    lcpCop[CPCODE_TERM_ACK-1].fsmevent = RTA;
-    lcpCop[CPCODE_PROT_REJ-1].encode = LcpEncodePJ;
+    lcpCop[CPCODE_CONF_REQ].fsmevent = RCR;
+    lcpCop[CPCODE_CONF_REQ].encode = LcpEncodeReg;
+    lcpCop[CPCODE_CONF_ACK].fsmevent = RCA;
+    lcpCop[CPCODE_CONF_ACK].encode = LcpEncodeReg;
+    lcpCop[CPCODE_CONF_NAK].fsmevent = RCN;
+    lcpCop[CPCODE_CONF_NAK].encode = LcpEncodeReg;
+    lcpCop[CPCODE_CONF_REJ].fsmevent = RCJ;
+    lcpCop[CPCODE_CONF_REJ].encode = LcpEncodeRejectReg;
+/*    lcpCop[CPCODE_CODE_REJ].fsmevent = RXCJ;*/
+    lcpCop[CPCODE_PROT_REJ].fsmevent = RXPJ;
+    lcpCop[CPCODE_TERM_REQ].fsmevent = RTR;
+    lcpCop[CPCODE_TERM_ACK].fsmevent = RTA;
+    lcpCop[CPCODE_PROT_REJ].encode = LcpEncodePJ;
 
-    lcpCop[CPCODE_ECHO_REQ-1].encode = LcpEncodeEcho;
-    lcpCop[CPCODE_ECHO_REQ-1].fsmevent = RXRequest;
-    lcpCop[CPCODE_ECHO_REP-1].encode = LcpEncodeEcho;
-    lcpCop[CPCODE_ECHO_REP-1].fsmevent = RXReply;
+    lcpCop[CPCODE_ECHO_REQ].encode = LcpEncodeEcho;
+    lcpCop[CPCODE_ECHO_REQ].fsmevent = RXRequest;
+    lcpCop[CPCODE_ECHO_REP].encode = LcpEncodeEcho;
+    lcpCop[CPCODE_ECHO_REP].fsmevent = RXReply;
     lcpFsm.tlu = TLU;
     lcpFsm.tlf = TLF;
     lcpFsm.tld = TLD;
