@@ -11,7 +11,7 @@ typedef	enum {
 } runmode_t;
 
 typedef enum {
-    AUTH_SERVER_NONE,
+    AUTH_SERVER_NONE,   /* is not a auth server!! */
     AUTH_SERVER_FILE,
     AUTH_SERVER_UNIX,
     AUTH_SERVER_RADIUS
